==> jc-1.4.0.tar.gz: gnu/xml/transform/NumberNode.h <==
// final class gnu.xml.transform.NumberNode

// class file dependencies
// @dep_class 51c9cbf326b4d63b gnu_xml_transform_AbstractNumberNode
// @dep_class d706b77e13451fa5 gnu_xml_transform_NumberNode
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_AbstractNumberNode

#include "gnu/xml/transform/AbstractNumberNode.h"

#ifndef _JC_gnu_xml_transform_NumberNode_H_
#define _JC_gnu_xml_transform_NumberNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_NumberNode$sub_refs	_jc_gnu_xml_transform_NumberNode$sub_refs;
typedef struct _jc_gnu_xml_transform_NumberNode$sub_nonrefs	_jc_gnu_xml_transform_NumberNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_NumberNode$refs	_jc_gnu_xml_transform_NumberNode$refs;
typedef struct _jc_gnu_xml_transform_NumberNode$nonrefs	_jc_gnu_xml_transform_NumberNode$nonrefs;
typedef struct _jc_gnu_xml_transform_NumberNode$object	_jc_gnu_xml_transform_NumberNode$object;

typedef const struct _jc_gnu_xml_transform_NumberNode$vmethods	_jc_gnu_xml_transform_NumberNode$vmethods;
typedef const struct _jc_gnu_xml_transform_NumberNode$vtable	_jc_gnu_xml_transform_NumberNode$vtable;
typedef const struct _jc_gnu_xml_transform_NumberNode$vtype	_jc_gnu_xml_transform_NumberNode$vtype;

// Constructors
extern void _jc_gnu_xml_transform_NumberNode$method$_init$ead97ce7c1144e80(_jc_env *, struct _jc_gnu_xml_transform_NumberNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_NumberNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_NumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
extern _jc_int_array *_jc_gnu_xml_transform_NumberNode$method$compute$51e66c80abac24fa(_jc_env *, struct _jc_gnu_xml_transform_NumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_NumberNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_NumberNode$method_info$compute$51e66c80abac24fa;

// Virtual methods structure
struct _jc_gnu_xml_transform_NumberNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_NumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
	_jc_int_array	*(*compute$51e66c80abac24fa)(_jc_env *, struct _jc_gnu_xml_transform_NumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_object *, jint, jint);
};

// Vtable
struct _jc_gnu_xml_transform_NumberNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_AbstractNumberNode$vmethods	gnu_xml_transform_AbstractNumberNode;
	_jc_gnu_xml_transform_NumberNode$vmethods	gnu_xml_transform_NumberNode;
};

// Vtype
struct _jc_gnu_xml_transform_NumberNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_NumberNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_NumberNode$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*value;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_NumberNode$refs {
    _jc_gnu_xml_transform_NumberNode$sub_refs	gnu_xml_transform_NumberNode;
    _jc_gnu_xml_transform_AbstractNumberNode$sub_refs	gnu_xml_transform_AbstractNumberNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_NumberNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_NumberNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_AbstractNumberNode$sub_nonrefs	gnu_xml_transform_AbstractNumberNode;
    _jc_gnu_xml_transform_NumberNode$sub_nonrefs	gnu_xml_transform_NumberNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_NumberNode$object {
	_jc_gnu_xml_transform_NumberNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_NumberNode$vtype	*vtype;
	_jc_gnu_xml_transform_NumberNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_NumberNode$vtype _jc_gnu_xml_transform_NumberNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_NumberNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_NumberNode$class_object;

#endif	/* _JC_gnu_xml_transform_NumberNode_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/NumberNode.h <==
// final class gnu.xml.transform.NumberNode

// class file dependencies
// @dep_class 51c9cbf326b4d63b gnu_xml_transform_AbstractNumberNode
// @dep_class d706b77e13451fa5 gnu_xml_transform_NumberNode
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_AbstractNumberNode

#include "gnu/xml/transform/AbstractNumberNode.h"

#ifndef _JC_gnu_xml_transform_NumberNode_H_
#define _JC_gnu_xml_transform_NumberNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_NumberNode$sub_refs	_jc_gnu_xml_transform_NumberNode$sub_refs;
typedef struct _jc_gnu_xml_transform_NumberNode$sub_nonrefs	_jc_gnu_xml_transform_NumberNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_NumberNode$refs	_jc_gnu_xml_transform_NumberNode$refs;
typedef struct _jc_gnu_xml_transform_NumberNode$nonrefs	_jc_gnu_xml_transform_NumberNode$nonrefs;
typedef struct _jc_gnu_xml_transform_NumberNode$object	_jc_gnu_xml_transform_NumberNode$object;

typedef const struct _jc_gnu_xml_transform_NumberNode$vmethods	_jc_gnu_xml_transform_NumberNode$vmethods;
typedef const struct _jc_gnu_xml_transform_NumberNode$vtable	_jc_gnu_xml_transform_NumberNode$vtable;
typedef const struct _jc_gnu_xml_transform_NumberNode$vtype	_jc_gnu_xml_transform_NumberNode$vtype;

// Constructors
extern void _jc_gnu_xml_transform_NumberNode$method$_init$ead97ce7c1144e80(_jc_env *, struct _jc_gnu_xml_transform_NumberNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_NumberNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_NumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
extern _jc_int_array *_jc_gnu_xml_transform_NumberNode$method$compute$51e66c80abac24fa(_jc_env *, struct _jc_gnu_xml_transform_NumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_NumberNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_NumberNode$method_info$compute$51e66c80abac24fa;

// Virtual methods structure
struct _jc_gnu_xml_transform_NumberNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_NumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
	_jc_int_array	*(*compute$51e66c80abac24fa)(_jc_env *, struct _jc_gnu_xml_transform_NumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_NumberNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_AbstractNumberNode$vmethods	gnu_xml_transform_AbstractNumberNode;
	_jc_gnu_xml_transform_NumberNode$vmethods	gnu_xml_transform_NumberNode;
};

// Vtype
struct _jc_gnu_xml_transform_NumberNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_NumberNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_NumberNode$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*value;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_NumberNode$refs {
    _jc_gnu_xml_transform_NumberNode$sub_refs	gnu_xml_transform_NumberNode;
    _jc_gnu_xml_transform_AbstractNumberNode$sub_refs	gnu_xml_transform_AbstractNumberNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_NumberNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_NumberNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_AbstractNumberNode$sub_nonrefs	gnu_xml_transform_AbstractNumberNode;
    _jc_gnu_xml_transform_NumberNode$sub_nonrefs	gnu_xml_transform_NumberNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_NumberNode$object {
	_jc_gnu_xml_transform_NumberNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_NumberNode$vtype	*vtype;
	_jc_gnu_xml_transform_NumberNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_NumberNode$vtype _jc_gnu_xml_transform_NumberNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_NumberNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_NumberNode$class_object;

#endif	/* _JC_gnu_xml_transform_NumberNode_H_ */
